# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class CloudRegion(Enum):
    AWS_US_EAST_1 = "AWS_US_EAST_1"
    AWS_US_EAST_2 = "AWS_US_EAST_2"
    AWS_US_WEST_1 = "AWS_US_WEST_1"
    AWS_US_WEST_2 = "AWS_US_WEST_2"
    AWS_EU_WEST_1 = "AWS_EU_WEST_1"
    AWS_EU_CENTRAL_1 = "AWS_EU_CENTRAL_1"
    AWS_AP_SOUTHEAST_1 = "AWS_AP_SOUTHEAST_1"
    AWS_AP_SOUTHEAST_2 = "AWS_AP_SOUTHEAST_2"
    AWS_AP_NORTHEAST_1 = "AWS_AP_NORTHEAST_1"
    AWS_AP_NORTHEAST_2 = "AWS_AP_NORTHEAST_2"
    AWS_AP_SOUTH_1 = "AWS_AP_SOUTH_1"
    AWS_SA_EAST_1 = "AWS_SA_EAST_1"
    AWS_EU_WEST_2 = "AWS_EU_WEST_2"
    AWS_EU_WEST_3 = "AWS_EU_WEST_3"
    AWS_CA_CENTRAL_1 = "AWS_CA_CENTRAL_1"
    AWS_EU_NORTH_1 = "AWS_EU_NORTH_1"
    GOOGLE_US_CENTRAL_1 = "GOOGLE_US_CENTRAL_1"
    GOOGLE_US_EAST_1 = "GOOGLE_US_EAST_1"
    GOOGLE_ASIA_EAST_1 = "GOOGLE_ASIA_EAST_1"
    GOOGLE_EUROPE_WEST_1 = "GOOGLE_EUROPE_WEST_1"
    GOOGLE_US_WEST_1 = "GOOGLE_US_WEST_1"
    GOOGLE_ASIA_EAST_2 = "GOOGLE_ASIA_EAST_2"
    GOOGLE_ASIA_NORTHEAST_1 = "GOOGLE_ASIA_NORTHEAST_1"
    GOOGLE_ASIA_SOUTH_1 = "GOOGLE_ASIA_SOUTH_1"
    GOOGLE_ASIA_SOUTHEAST_1 = "GOOGLE_ASIA_SOUTHEAST_1"
    GOOGLE_AUSTRALIA_SOUTHEAST_1 = "GOOGLE_AUSTRALIA_SOUTHEAST_1"
    GOOGLE_EUROPE_NORTH_1 = "GOOGLE_EUROPE_NORTH_1"
    GOOGLE_EUROPE_WEST_2 = "GOOGLE_EUROPE_WEST_2"
    GOOGLE_EUROPE_WEST_3 = "GOOGLE_EUROPE_WEST_3"
    GOOGLE_EUROPE_WEST_4 = "GOOGLE_EUROPE_WEST_4"
    GOOGLE_NORTHAMERICA_NORTHEAST_1 = "GOOGLE_NORTHAMERICA_NORTHEAST_1"
    GOOGLE_SOUTHAMERICA_EAST_1 = "GOOGLE_SOUTHAMERICA_EAST_1"
    GOOGLE_US_EAST_4 = "GOOGLE_US_EAST_4"
    GOOGLE_US_WEST_2 = "GOOGLE_US_WEST_2"
    GOOGLE_ME_CENTRAL_2 = "GOOGLE_ME_CENTRAL_2"
    AZURE_ASIA_EAST = "AZURE_ASIA_EAST"
    AZURE_ASIA_SOUTHEAST = "AZURE_ASIA_SOUTHEAST"
    AZURE_AUSTRALIA_EAST = "AZURE_AUSTRALIA_EAST"
    AZURE_AUSTRALIA_SOUTHEAST = "AZURE_AUSTRALIA_SOUTHEAST"
    AZURE_BRAZIL_SOUTH = "AZURE_BRAZIL_SOUTH"
    AZURE_CANADA_CENTRAL = "AZURE_CANADA_CENTRAL"
    AZURE_EUROPE_NORTH = "AZURE_EUROPE_NORTH"
    AZURE_EUROPE_WEST = "AZURE_EUROPE_WEST"
    AZURE_FRANCE_CENTRAL = "AZURE_FRANCE_CENTRAL"
    AZURE_GERMANY_WESTCENTRAL = "AZURE_GERMANY_WESTCENTRAL"
    AZURE_INDIA_CENTRAL = "AZURE_INDIA_CENTRAL"
    AZURE_INDIA_SOUTH = "AZURE_INDIA_SOUTH"
    AZURE_JAPAN_EAST = "AZURE_JAPAN_EAST"
    AZURE_JAPAN_WEST = "AZURE_JAPAN_WEST"
    AZURE_KOREA_CENTRAL = "AZURE_KOREA_CENTRAL"
    AZURE_UAE_NORTH = "AZURE_UAE_NORTH"
    AZURE_US_CENTRAL = "AZURE_US_CENTRAL"
    AZURE_US_EAST = "AZURE_US_EAST"
    AZURE_US_EAST2 = "AZURE_US_EAST2"
    AZURE_US_WEST = "AZURE_US_WEST"
    AZURE_US_WEST2 = "AZURE_US_WEST2"
    AZURE_US_SOUTH_CENTRAL = "AZURE_US_SOUTH_CENTRAL"
    AZURE_US_NORTH_CENTRAL = "AZURE_US_NORTH_CENTRAL"
    AZURE_UK_SOUTH = "AZURE_UK_SOUTH"
    AKAMAI_BR_GRU = "AKAMAI_BR_GRU"
    AKAMAI_ES_MAD = "AKAMAI_ES_MAD"
    AKAMAI_FR_PAR = "AKAMAI_FR_PAR"
    AKAMAI_ID_CGK = "AKAMAI_ID_CGK"
    AKAMAI_IN_MAA = "AKAMAI_IN_MAA"
    AKAMAI_IT_MIL = "AKAMAI_IT_MIL"
    AKAMAI_JP_OSA = "AKAMAI_JP_OSA"
    AKAMAI_NL_AMS = "AKAMAI_NL_AMS"
    AKAMAI_SE_STO = "AKAMAI_SE_STO"
    AKAMAI_US_LAX = "AKAMAI_US_LAX"
    AKAMAI_US_MIA = "AKAMAI_US_MIA"
    AKAMAI_US_ORD = "AKAMAI_US_ORD"
    AKAMAI_US_SEA = "AKAMAI_US_SEA"
    OCI_EU_FRANKFURT_1 = "OCI_EU_FRANKFURT_1"
    OCI_US_ASHBURN_1 = "OCI_US_ASHBURN_1"
    NORTH_AMERICA = "NORTH_AMERICA"
    SOUTH_AMERICA = "SOUTH_AMERICA"
    EUROPE = "EUROPE"
    AFRICA = "AFRICA"
    ASIA = "ASIA"
    AUSTRALIA = "AUSTRALIA"
    AWS = "AWS"
    GOOGLE = "GOOGLE"
    EXTERNAL = "EXTERNAL"
    AUTO = "AUTO"



from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.drm.speke.speke_api import SpekeApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.drm.speke.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.drm.speke.speke_drm_list_query_params import SpekeDrmListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.metadata import Metadata
import pprint
import six


class SceneAnalysisDetailsResponse(object):
    @poscheck_model
    def __init__(self,
                 scenes=None,
                 description=None,
                 keywords=None,
                 ratings=None,
                 sensitive_topics=None,
                 iab_sensitive_topic_taxonomies=None,
                 metadata=None):
        # type: (list[Scene], string_types, list[string_types], list[Rating], list[string_types], list[string_types], Metadata) -> None

        self._scenes = list()
        self._description = None
        self._keywords = list()
        self._ratings = list()
        self._sensitive_topics = list()
        self._iab_sensitive_topic_taxonomies = list()
        self._metadata = None
        self.discriminator = None

        if scenes is not None:
            self.scenes = scenes
        if description is not None:
            self.description = description
        if keywords is not None:
            self.keywords = keywords
        if ratings is not None:
            self.ratings = ratings
        if sensitive_topics is not None:
            self.sensitive_topics = sensitive_topics
        if iab_sensitive_topic_taxonomies is not None:
            self.iab_sensitive_topic_taxonomies = iab_sensitive_topic_taxonomies
        if metadata is not None:
            self.metadata = metadata

    @property
    def openapi_types(self):
        types = {
            'scenes': 'list[Scene]',
            'description': 'string_types',
            'keywords': 'list[string_types]',
            'ratings': 'list[Rating]',
            'sensitive_topics': 'list[string_types]',
            'iab_sensitive_topic_taxonomies': 'list[string_types]',
            'metadata': 'Metadata'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'scenes': 'scenes',
            'description': 'description',
            'keywords': 'keywords',
            'ratings': 'ratings',
            'sensitive_topics': 'sensitiveTopics',
            'iab_sensitive_topic_taxonomies': 'iabSensitiveTopicTaxonomies',
            'metadata': 'metadata'
        }
        return attributes

    @property
    def scenes(self):
        # type: () -> list[Scene]
        """Gets the scenes of this SceneAnalysisDetailsResponse.


        :return: The scenes of this SceneAnalysisDetailsResponse.
        :rtype: list[Scene]
        """
        return self._scenes

    @scenes.setter
    def scenes(self, scenes):
        # type: (list) -> None
        """Sets the scenes of this SceneAnalysisDetailsResponse.


        :param scenes: The scenes of this SceneAnalysisDetailsResponse.
        :type: list[Scene]
        """

        if scenes is not None:
            if not isinstance(scenes, list):
                raise TypeError("Invalid type for `scenes`, type has to be `list[Scene]`")

        self._scenes = scenes

    @property
    def description(self):
        # type: () -> string_types
        """Gets the description of this SceneAnalysisDetailsResponse.


        :return: The description of this SceneAnalysisDetailsResponse.
        :rtype: string_types
        """
        return self._description

    @description.setter
    def description(self, description):
        # type: (string_types) -> None
        """Sets the description of this SceneAnalysisDetailsResponse.


        :param description: The description of this SceneAnalysisDetailsResponse.
        :type: string_types
        """

        if description is not None:
            if not isinstance(description, string_types):
                raise TypeError("Invalid type for `description`, type has to be `string_types`")

        self._description = description

    @property
    def keywords(self):
        # type: () -> list[string_types]
        """Gets the keywords of this SceneAnalysisDetailsResponse.


        :return: The keywords of this SceneAnalysisDetailsResponse.
        :rtype: list[string_types]
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        # type: (list) -> None
        """Sets the keywords of this SceneAnalysisDetailsResponse.


        :param keywords: The keywords of this SceneAnalysisDetailsResponse.
        :type: list[string_types]
        """

        if keywords is not None:
            if not isinstance(keywords, list):
                raise TypeError("Invalid type for `keywords`, type has to be `list[string_types]`")

        self._keywords = keywords

    @property
    def ratings(self):
        # type: () -> list[Rating]
        """Gets the ratings of this SceneAnalysisDetailsResponse.


        :return: The ratings of this SceneAnalysisDetailsResponse.
        :rtype: list[Rating]
        """
        return self._ratings

    @ratings.setter
    def ratings(self, ratings):
        # type: (list) -> None
        """Sets the ratings of this SceneAnalysisDetailsResponse.


        :param ratings: The ratings of this SceneAnalysisDetailsResponse.
        :type: list[Rating]
        """

        if ratings is not None:
            if not isinstance(ratings, list):
                raise TypeError("Invalid type for `ratings`, type has to be `list[Rating]`")

        self._ratings = ratings

    @property
    def sensitive_topics(self):
        # type: () -> list[string_types]
        """Gets the sensitive_topics of this SceneAnalysisDetailsResponse.


        :return: The sensitive_topics of this SceneAnalysisDetailsResponse.
        :rtype: list[string_types]
        """
        return self._sensitive_topics

    @sensitive_topics.setter
    def sensitive_topics(self, sensitive_topics):
        # type: (list) -> None
        """Sets the sensitive_topics of this SceneAnalysisDetailsResponse.


        :param sensitive_topics: The sensitive_topics of this SceneAnalysisDetailsResponse.
        :type: list[string_types]
        """

        if sensitive_topics is not None:
            if not isinstance(sensitive_topics, list):
                raise TypeError("Invalid type for `sensitive_topics`, type has to be `list[string_types]`")

        self._sensitive_topics = sensitive_topics

    @property
    def iab_sensitive_topic_taxonomies(self):
        # type: () -> list[string_types]
        """Gets the iab_sensitive_topic_taxonomies of this SceneAnalysisDetailsResponse.


        :return: The iab_sensitive_topic_taxonomies of this SceneAnalysisDetailsResponse.
        :rtype: list[string_types]
        """
        return self._iab_sensitive_topic_taxonomies

    @iab_sensitive_topic_taxonomies.setter
    def iab_sensitive_topic_taxonomies(self, iab_sensitive_topic_taxonomies):
        # type: (list) -> None
        """Sets the iab_sensitive_topic_taxonomies of this SceneAnalysisDetailsResponse.


        :param iab_sensitive_topic_taxonomies: The iab_sensitive_topic_taxonomies of this SceneAnalysisDetailsResponse.
        :type: list[string_types]
        """

        if iab_sensitive_topic_taxonomies is not None:
            if not isinstance(iab_sensitive_topic_taxonomies, list):
                raise TypeError("Invalid type for `iab_sensitive_topic_taxonomies`, type has to be `list[string_types]`")

        self._iab_sensitive_topic_taxonomies = iab_sensitive_topic_taxonomies

    @property
    def metadata(self):
        # type: () -> Metadata
        """Gets the metadata of this SceneAnalysisDetailsResponse.


        :return: The metadata of this SceneAnalysisDetailsResponse.
        :rtype: Metadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        # type: (Metadata) -> None
        """Sets the metadata of this SceneAnalysisDetailsResponse.


        :param metadata: The metadata of this SceneAnalysisDetailsResponse.
        :type: Metadata
        """

        if metadata is not None:
            if not isinstance(metadata, Metadata):
                raise TypeError("Invalid type for `metadata`, type has to be `Metadata`")

        self._metadata = metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SceneAnalysisDetailsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class CdnUsage(object):
    @poscheck_model
    def __init__(self,
                 from_=None,
                 to=None,
                 storage_usage=None,
                 transfer_usage=None):
        # type: (datetime, datetime, float, float) -> None

        self._from_ = None
        self._to = None
        self._storage_usage = None
        self._transfer_usage = None
        self.discriminator = None

        if from_ is not None:
            self.from_ = from_
        if to is not None:
            self.to = to
        if storage_usage is not None:
            self.storage_usage = storage_usage
        if transfer_usage is not None:
            self.transfer_usage = transfer_usage

    @property
    def openapi_types(self):
        types = {
            'from_': 'datetime',
            'to': 'datetime',
            'storage_usage': 'float',
            'transfer_usage': 'float'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'from_': 'from',
            'to': 'to',
            'storage_usage': 'storageUsage',
            'transfer_usage': 'transferUsage'
        }
        return attributes

    @property
    def from_(self):
        # type: () -> datetime
        """Gets the from_ of this CdnUsage.

        UTC timestamp which marks the beginning of the time period for which the usage statistics are retrieved.

        :return: The from_ of this CdnUsage.
        :rtype: datetime
        """
        return self._from_

    @from_.setter
    def from_(self, from_):
        # type: (datetime) -> None
        """Sets the from_ of this CdnUsage.

        UTC timestamp which marks the beginning of the time period for which the usage statistics are retrieved.

        :param from_: The from_ of this CdnUsage.
        :type: datetime
        """

        if from_ is not None:
            if not isinstance(from_, datetime):
                raise TypeError("Invalid type for `from_`, type has to be `datetime`")

        self._from_ = from_

    @property
    def to(self):
        # type: () -> datetime
        """Gets the to of this CdnUsage.

        UTC timestamp which marks the end of the time period for which the usage statistics are retrieved. The end date is exclusive. For example, if end is 2019-03-29T13:05:00Z, the cost and usage data are retrieved from the start date up to, but not including, 2019-03-29T13:05:00Z.

        :return: The to of this CdnUsage.
        :rtype: datetime
        """
        return self._to

    @to.setter
    def to(self, to):
        # type: (datetime) -> None
        """Sets the to of this CdnUsage.

        UTC timestamp which marks the end of the time period for which the usage statistics are retrieved. The end date is exclusive. For example, if end is 2019-03-29T13:05:00Z, the cost and usage data are retrieved from the start date up to, but not including, 2019-03-29T13:05:00Z.

        :param to: The to of this CdnUsage.
        :type: datetime
        """

        if to is not None:
            if not isinstance(to, datetime):
                raise TypeError("Invalid type for `to`, type has to be `datetime`")

        self._to = to

    @property
    def storage_usage(self):
        # type: () -> float
        """Gets the storage_usage of this CdnUsage.

        Storage usage in GB per month.

        :return: The storage_usage of this CdnUsage.
        :rtype: float
        """
        return self._storage_usage

    @storage_usage.setter
    def storage_usage(self, storage_usage):
        # type: (float) -> None
        """Sets the storage_usage of this CdnUsage.

        Storage usage in GB per month.

        :param storage_usage: The storage_usage of this CdnUsage.
        :type: float
        """

        if storage_usage is not None:
            if not isinstance(storage_usage, (float, int)):
                raise TypeError("Invalid type for `storage_usage`, type has to be `float`")

        self._storage_usage = storage_usage

    @property
    def transfer_usage(self):
        # type: () -> float
        """Gets the transfer_usage of this CdnUsage.

        Transfer usage in GB.

        :return: The transfer_usage of this CdnUsage.
        :rtype: float
        """
        return self._transfer_usage

    @transfer_usage.setter
    def transfer_usage(self, transfer_usage):
        # type: (float) -> None
        """Sets the transfer_usage of this CdnUsage.

        Transfer usage in GB.

        :param transfer_usage: The transfer_usage of this CdnUsage.
        :type: float
        """

        if transfer_usage is not None:
            if not isinstance(transfer_usage, (float, int)):
                raise TypeError("Invalid type for `transfer_usage`, type has to be `float`")

        self._transfer_usage = transfer_usage

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CdnUsage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class SrtMode(Enum):
    LISTENER = "LISTENER"
    CALLER = "CALLER"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.insertable_content import InsertableContent
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.encodings.live.insertable_content.schedule.schedule_api import ScheduleApi
from bitmovin_api_sdk.encoding.encodings.live.insertable_content.scheduled.scheduled_api import ScheduledApi
from bitmovin_api_sdk.encoding.encodings.live.insertable_content.stop.stop_api import StopApi
from bitmovin_api_sdk.encoding.encodings.live.insertable_content.insertable_content_list_query_params import InsertableContentListQueryParams


class InsertableContentApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(InsertableContentApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.schedule = ScheduleApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.scheduled = ScheduledApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.stop = StopApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, insertable_content, **kwargs):
        # type: (string_types, InsertableContent, dict) -> InsertableContent
        """Create Insertable Content

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param insertable_content: The insertable content to be created
        :type insertable_content: InsertableContent, required
        :return: Insertable content
        :rtype: InsertableContent
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/live/insertable-content',
            insertable_content,
            path_params={'encoding_id': encoding_id},
            type=InsertableContent,
            **kwargs
        )

    def list(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, InsertableContentListQueryParams, dict) -> InsertableContent
        """List Insertable Content

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: InsertableContentListQueryParams
        :return: List of insertable content
        :rtype: InsertableContent
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/live/insertable-content',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=InsertableContent,
            **kwargs
        )



from bitmovin_api_sdk.encoding.filters.interlace.interlace_api import InterlaceApi
from bitmovin_api_sdk.encoding.filters.interlace.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.filters.interlace.interlace_filter_list_query_params import InterlaceFilterListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class LiveStandbyPoolUpdate(object):
    @poscheck_model
    def __init__(self,
                 target_pool_size=None,
                 encoding_template=None):
        # type: (int, string_types) -> None

        self._target_pool_size = None
        self._encoding_template = None
        self.discriminator = None

        if target_pool_size is not None:
            self.target_pool_size = target_pool_size
        if encoding_template is not None:
            self.encoding_template = encoding_template

    @property
    def openapi_types(self):
        types = {
            'target_pool_size': 'int',
            'encoding_template': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'target_pool_size': 'targetPoolSize',
            'encoding_template': 'encodingTemplate'
        }
        return attributes

    @property
    def target_pool_size(self):
        # type: () -> int
        """Gets the target_pool_size of this LiveStandbyPoolUpdate.

        Number of instances to keep ready for streaming while the pool is running

        :return: The target_pool_size of this LiveStandbyPoolUpdate.
        :rtype: int
        """
        return self._target_pool_size

    @target_pool_size.setter
    def target_pool_size(self, target_pool_size):
        # type: (int) -> None
        """Sets the target_pool_size of this LiveStandbyPoolUpdate.

        Number of instances to keep ready for streaming while the pool is running

        :param target_pool_size: The target_pool_size of this LiveStandbyPoolUpdate.
        :type: int
        """

        if target_pool_size is not None:
            if target_pool_size is not None and target_pool_size < 0:
                raise ValueError("Invalid value for `target_pool_size`, must be a value greater than or equal to `0`")
            if not isinstance(target_pool_size, int):
                raise TypeError("Invalid type for `target_pool_size`, type has to be `int`")

        self._target_pool_size = target_pool_size

    @property
    def encoding_template(self):
        # type: () -> string_types
        """Gets the encoding_template of this LiveStandbyPoolUpdate.

        Base64 encoded template used to start the encodings in the pool

        :return: The encoding_template of this LiveStandbyPoolUpdate.
        :rtype: string_types
        """
        return self._encoding_template

    @encoding_template.setter
    def encoding_template(self, encoding_template):
        # type: (string_types) -> None
        """Sets the encoding_template of this LiveStandbyPoolUpdate.

        Base64 encoded template used to start the encodings in the pool

        :param encoding_template: The encoding_template of this LiveStandbyPoolUpdate.
        :type: string_types
        """

        if encoding_template is not None:
            if not isinstance(encoding_template, string_types):
                raise TypeError("Invalid type for `encoding_template`, type has to be `string_types`")

        self._encoding_template = encoding_template

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveStandbyPoolUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.representations_api import RepresentationsApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.vtt.vtt_api import VttApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.imsc.imsc_api import ImscApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.sprite.sprite_api import SpriteApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.fmp4.fmp4_api import Fmp4Api
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.chunked_text.chunked_text_api import ChunkedTextApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.cmaf.cmaf_api import CmafApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.mp4.mp4_api import Mp4Api
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.webm.webm_api import WebmApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.progressive_webm.progressive_webm_api import ProgressiveWebmApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.dash_representation_list_query_params import DashRepresentationListQueryParams



from bitmovin_api_sdk.encoding.configurations.video.mjpeg.mjpeg_api import MjpegApi
from bitmovin_api_sdk.encoding.configurations.video.mjpeg.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.video.mjpeg.mjpeg_video_configuration_list_query_params import MjpegVideoConfigurationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DashScte35EventStreamSignalling(Enum):
    XML = "XML"
    XML_BIN = "XML_BIN"
